@@ -141,8 +141,8 @@ class RootInfo extends PlaceInfo {
                 return;
 
             this._proxy = obj;
-            this._proxy.connect('g-properties-changed',
-                this._propertiesChanged.bind(this));
+            this._proxy.connectObject('g-properties-changed',
+                this._propertiesChanged.bind(this), this);
             this._propertiesChanged(obj);
         });
     }
@@ -161,10 +161,8 @@ class RootInfo extends PlaceInfo {
     }
 
     destroy() {
-        if (this._proxy) {
-            this._proxy.run_dispose();
-            this._proxy = null;
-        }
+        this._proxy?.disconnectObject(this);
+        this._proxy = null;
         super.destroy();
     }
 }
