@@ -10,6 +10,7 @@ import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
 import Meta from 'gi://Meta';
+import Mtk from 'gi://Mtk';
 import Shell from 'gi://Shell';
 import St from 'gi://St';
 
@@ -17,10 +18,8 @@ import {Extension, gettext as _} from 'resource:///org/gnome/shell/extensions/ex
 
 import * as DND from 'resource:///org/gnome/shell/ui/dnd.js';
 import * as Main from 'resource:///org/gnome/shell/ui/main.js';
-import * as Overview from 'resource:///org/gnome/shell/ui/overview.js';
 import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
 
-import {WindowPicker, WindowPickerToggle} from './windowPicker.js';
 import {WorkspaceIndicator} from './workspaceIndicator.js';
 
 const ICON_TEXTURE_SIZE = 24;
@@ -123,10 +122,10 @@ class WindowTitle extends St.BoxLayout {
         this._metaWindow = metaWindow;
 
         this._icon = new St.Bin({style_class: 'window-button-icon'});
-        this.add(this._icon);
+        this.add_child(this._icon);
         this.label_actor = new St.Label({y_align: Clutter.ActorAlign.CENTER});
         this.label_actor.clutter_text.single_line_mode = true;
-        this.add(this.label_actor);
+        this.add_child(this.label_actor);
 
         this._textureCache = St.TextureCache.get_default();
         this._textureCache.connectObject('icon-theme-changed',
@@ -369,7 +368,7 @@ class BaseButton extends St.Button {
     }
 
     _getIconGeometry() {
-        let rect = new Meta.Rectangle();
+        const rect = new Mtk.Rectangle();
 
         [rect.x, rect.y] = this.get_transformed_position();
         [rect.width, rect.height] = this.get_transformed_size();
@@ -412,7 +411,7 @@ class WindowButton extends BaseButton {
             this._onMenuStateChanged.bind(this));
         this._contextMenu.actor.hide();
         this._contextMenuManager.addMenu(this._contextMenu);
-        Main.uiGroup.add_actor(this._contextMenu.actor);
+        Main.uiGroup.add_child(this._contextMenu.actor);
 
         global.display.connectObject('notify::focus-window',
             () => this._updateStyle(), this);
@@ -538,25 +537,25 @@ class AppButton extends BaseButton {
         this._singleWindowTitle = new St.Bin({
             x_expand: true,
         });
-        stack.add_actor(this._singleWindowTitle);
+        stack.add_child(this._singleWindowTitle);
 
         this._multiWindowTitle = new St.BoxLayout({
             style_class: 'window-button-box',
             x_expand: true,
         });
-        stack.add_actor(this._multiWindowTitle);
+        stack.add_child(this._multiWindowTitle);
 
         this._icon = new St.Bin({
             style_class: 'window-button-icon',
             child: app.create_icon_texture(ICON_TEXTURE_SIZE),
         });
-        this._multiWindowTitle.add(this._icon);
+        this._multiWindowTitle.add_child(this._icon);
 
         let label = new St.Label({
             text: app.get_name(),
             y_align: Clutter.ActorAlign.CENTER,
         });
-        this._multiWindowTitle.add(label);
+        this._multiWindowTitle.add_child(label);
         this._multiWindowTitle.label_actor = label;
 
         this._menuManager = new PopupMenu.PopupMenuManager(this);
@@ -566,13 +565,13 @@ class AppButton extends BaseButton {
         this._menu.actor.hide();
         this._menu.connect('activate', this._onMenuActivate.bind(this));
         this._menuManager.addMenu(this._menu);
-        Main.uiGroup.add_actor(this._menu.actor);
+        Main.uiGroup.add_child(this._menu.actor);
 
         this._appContextMenu = new AppContextMenu(this);
         this._appContextMenu.connect('open-state-changed',
             this._onMenuStateChanged.bind(this));
         this._appContextMenu.actor.hide();
-        Main.uiGroup.add_actor(this._appContextMenu.actor);
+        Main.uiGroup.add_child(this._appContextMenu.actor);
 
         this._textureCache = St.TextureCache.get_default();
         this._textureCache.connectObject('icon-theme-changed', () => {
@@ -637,7 +636,7 @@ class AppButton extends BaseButton {
                 this._windowContextMenu = new WindowContextMenu(this, this.metaWindow);
                 this._windowContextMenu.connect(
                     'open-state-changed', this._onMenuStateChanged.bind(this));
-                Main.uiGroup.add_actor(this._windowContextMenu.actor);
+                Main.uiGroup.add_child(this._windowContextMenu.actor);
                 this._windowContextMenu.actor.hide();
                 this._contextMenuManager.addMenu(this._windowContextMenu);
             }
@@ -682,7 +681,7 @@ class AppButton extends BaseButton {
                 for (let i = 0; i < windows.length; i++) {
                     let windowTitle = new WindowTitle(windows[i]);
                     let item = new PopupMenu.PopupBaseMenuItem();
-                    item.add_actor(windowTitle);
+                    item.add_child(windowTitle);
                     item._window = windows[i];
                     this._menu.addMenuItem(item);
                 }
@@ -728,13 +727,7 @@ class WindowList extends St.Widget {
         this._monitor = monitor;
 
         let box = new St.BoxLayout({x_expand: true, y_expand: true});
-        this.add_actor(box);
-
-        let toggle = new WindowPickerToggle();
-        box.add_actor(toggle);
-
-        toggle.connect('notify::checked',
-            this._updateWindowListVisibility.bind(this));
+        this.add_child(box);
 
         let layout = new Clutter.BoxLayout({homogeneous: true});
         this._windowList = new St.Widget({
@@ -755,7 +748,7 @@ class WindowList extends St.Widget {
         this._windowList.connect('scroll-event', this._onScrollEvent.bind(this));
 
         let indicatorsBox = new St.BoxLayout({x_align: Clutter.ActorAlign.END});
-        box.add(indicatorsBox);
+        box.add_child(indicatorsBox);
 
         this._workspaceIndicator = new WorkspaceIndicator();
         indicatorsBox.add_child(this._workspaceIndicator.container);
@@ -828,8 +821,8 @@ class WindowList extends St.Widget {
         }, this);
 
         this._windowSignals = new Map();
-        this._windowCreatedId = global.display.connect(
-            'window-created', (dsp, win) => this._addWindow(win));
+        global.display.connectObject(
+            'window-created', (dsp, win) => this._addWindow(win), this);
 
         Main.xdndHandler.connectObject(
             'drag-begin', () => this._monitorDrag(),
@@ -844,8 +837,8 @@ class WindowList extends St.Widget {
         this._dndWindow = null;
 
         this._settings = settings;
-        this._settings.connect('changed::grouping-mode',
-            () => this._groupingModeChanged());
+        this._settings.connectObject('changed::grouping-mode',
+            () => this._groupingModeChanged(), this);
         this._grouped = undefined;
         this._groupingModeChanged();
     }
@@ -883,20 +876,6 @@ class WindowList extends St.Widget {
         this._workspaceIndicator.visible = hasWorkspaces && workspacesOnMonitor;
     }
 
-    _updateWindowListVisibility() {
-        const {windowPicker} = Extension.lookupByURL(import.meta.url);
-        const visible = !windowPicker.visible;
-
-        this._windowList.ease({
-            opacity: visible ? 255 : 0,
-            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
-            duration: Overview.ANIMATION_TIME,
-        });
-
-        this._windowList.reactive = visible;
-        this._windowList.get_children().forEach(c => (c.reactive = visible));
-    }
-
     _getPreferredUngroupedWindowListWidth() {
         if (this._windowList.get_n_children() === 0)
             return this._windowList.get_preferred_width(-1)[1];
@@ -1092,7 +1071,8 @@ class WindowList extends St.Widget {
 
         this._stopMonitoringDrag();
 
-        this._settings.run_dispose();
+        this._settings.disconnectObject();
+        this._settings = null;
 
         let windows = global.get_window_actors();
         for (let i = 0; i < windows.length; i++)
@@ -1105,7 +1085,6 @@ export default class WindowListExtension extends Extension {
         super(metadata);
 
         this._windowLists = null;
-        this._hideOverviewOrig = Main.overview.hide;
     }
 
     enable() {
@@ -1118,13 +1097,6 @@ export default class WindowListExtension extends Extension {
         Main.layoutManager.connectObject('monitors-changed',
             () => this._buildWindowLists(), this);
 
-        this.windowPicker = new WindowPicker();
-
-        Main.overview.hide = () => {
-            this.windowPicker.close();
-            this._hideOverviewOrig.call(Main.overview);
-        };
-
         this._buildWindowLists();
     }
 
@@ -1144,19 +1116,15 @@ export default class WindowListExtension extends Extension {
         if (!this._windowLists)
             return;
 
-        this._settings.disconnectObject(this);
         Main.layoutManager.disconnectObject(this);
+        this._settings.disconnectObject(this);
+        this._settings = null;
 
         this._windowLists.forEach(windowList => {
             windowList.hide();
             windowList.destroy();
         });
         this._windowLists = null;
-
-        this.windowPicker.destroy();
-        delete this.windowPicker;
-
-        Main.overview.hide = this._hideOverviewOrig;
     }
 
     someWindowListContains(actor) {
