@@ -1,29 +1,29 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2014 Sylvain Pasche <sylvain.pasche@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
-/* exported init buildPrefsWidget */
+import Adw from 'gi://Adw';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const {Adw, Gio, GLib, GObject, Gtk} = imports.gi;
-
-const ExtensionUtils = imports.misc.extensionUtils;
-
-const _ = ExtensionUtils.gettext;
-
-/** */
-function init() {
-    ExtensionUtils.initTranslations();
-}
+import {ExtensionPreferences, gettext as _} from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';
 
 class WindowListPrefsWidget extends Adw.PreferencesPage {
     static {
         GObject.registerClass(this);
     }
 
-    constructor() {
+    constructor(settings) {
         super();
 
         this._actionGroup = new Gio.SimpleActionGroup();
         this.insert_action_group('window-list', this._actionGroup);
 
-        this._settings = ExtensionUtils.getSettings();
+        this._settings = settings;
         this._actionGroup.add_action(
             this._settings.create_action('grouping-mode'));
         this._actionGroup.add_action(
@@ -84,9 +84,8 @@ class WindowListPrefsWidget extends Adw.PreferencesPage {
     }
 }
 
-/**
- * @returns {Gtk.Widget} - the prefs widget
- */
-function buildPrefsWidget() {
-    return new WindowListPrefsWidget();
+export default class WindowListPrefs extends ExtensionPreferences {
+    getPreferencesWidget() {
+        return new WindowListPrefsWidget(this.getSettings());
+    }
 }
